#!/bin/bash

SUMO_NET_XML_FILE="$1"
OUTPUT_FILE_PREFIX="$2"

print_usage() {
    echo "Usage: ./generate-ltm.sh <sumo_network_file> <output_ltm_file_prefix>"
    echo "  Where: "
    echo "    sumo_network_file: file path to the sumo-model-autogen generated sumo network file (osm.net.xml)."
    echo "    output_ltm_file_prefix: prefix of the output ltm file, without extension"
}

if [ "$#" -ne 2 ]; then
    echo "ERROR:Illegal number of parameters"
    print_usage
    exit 1
fi

if ! [ -f "$SUMO_NET_XML_FILE" ]; then
    echo "Sumo net.xml network file not found: $SUMO_NET_XML_FILE"
    print_usage
    exit 1
fi
echo "Generating ltm file..."

SHIFT_ARRAY=($(grep "netOffset" "$SUMO_NET_XML_FILE" | cut  -d "\"" -f 2 | tr "," " "))

LTM_FILE_PATH="${OUTPUT_FILE_PREFIX}.ltm"

cat <<EOF > "$LTM_FILE_PATH"
Do NOT modify this file.
This file contains segment data.
GlobalTarnsformX GlobalTarnsformY
-${SHIFT_ARRAY[0]} -${SHIFT_ARRAY[1]}
ID,StartX StartY StartTransformX StartTransformY,EndX EndY EndTransformX EndTransformY
EOF

echo "ltm file has been generated: $LTM_FILE_PATH"
